alloc_complex

Function alloc_complex 

pub fn alloc_complex<T: Float>(size: usize) -> Vec<Complex<T>>
Allocate an aligned buffer for complex values.

The returned vector is guaranteed to have its data pointer aligned to DEFAULT_ALIGNMENT bytes (64 bytes for AVX-512).

Note: This returns a standard Vec which may not be aligned. For guaranteed alignment, use AlignedBuffer::new().