alloc_complex_aligned

Function alloc_complex_aligned 

pub fn alloc_complex_aligned<T: Float>(size: usize) -> AlignedBuffer<Complex<T>>
Allocate an aligned buffer for complex values with guaranteed alignment.

The returned buffer is guaranteed to have its data pointer aligned to DEFAULT_ALIGNMENT bytes (64 bytes for AVX-512).