alloc_real_aligned

Function alloc_real_aligned 

pub fn alloc_real_aligned<T: Float>(size: usize) -> AlignedBuffer<T>
Allocate an aligned buffer for real values with guaranteed alignment.

The returned buffer is guaranteed to have its data pointer aligned to DEFAULT_ALIGNMENT bytes (64 bytes for AVX-512).