WisdomMergeResult

Struct WisdomMergeResult 

pub struct WisdomMergeResult {
    pub added: usize,
    pub replaced: usize,
    pub kept_existing: usize,
    pub skipped_invalid: usize,
    pub format_version: u32,
}
Statistics returned from a wisdom merge operation.

Returned by merge_from_string, merge_from_file, and the corresponding WisdomCache::merge_string method.

Fields

added: usize

Number of entries inserted because they were absent from the cache.

replaced: usize

Number of entries from the incoming data that replaced existing ones because they had a lower cost.

kept_existing: usize

Number of entries from the incoming data that were discarded because the existing cache entry already had a lower or equal cost.

skipped_invalid: usize

Number of entries skipped because of invalid / corrupt data.

format_version: u32

Format version found in the wisdom data.