Solver

Trait Solver 

pub trait Solver: Send + Sync {
    type Problem: Problem;
    type Plan: Plan<Problem = Self::Problem>;

    // Required methods
    fn problem_kind(&self) -> ProblemKind;
    fn make_plan<T>(
        &self,
        problem: &Self::Problem,
        planner: &mut Planner<T>,
    ) -> Option<Self::Plan>
       where T: Float;
    fn name(&self) -> &'static str;

    // Provided method
    fn priority(&self) -> i32 { ... }
}
Solver creates plans for specific problem types.

The planner iterates through registered solvers to find the best plan for a given problem.

Required Associated Types

type Problem: Problem

The problem type this solver handles.

type Plan: Plan<Problem = Self::Problem>

The plan type this solver produces.

Required Methods

fn problem_kind(&self) -> ProblemKind

Problem kind this solver handles.

fn make_plan<T>( &self, problem: &Self::Problem, planner: &mut Planner<T>, ) -> Option<Self::Plan>
where T: Float,

Attempt to create a plan for the given problem.

Returns None if this solver cannot handle the problem.

fn name(&self) -> &'static str

Solver name for debugging.

Provided Methods

fn priority(&self) -> i32

Priority hint (higher = try first).

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors