pool_with_threads

Function pool_with_threads 

pub fn pool_with_threads(num_threads: usize) -> RayonPool
Get a thread pool with the specified number of threads.

When the threading feature is enabled, returns a RayonPool with the specified thread count. Otherwise returns a SerialPool.