pub struct Plan<T: Float> { /* private fields */ }Expand description
A plan for executing FFT transforms.
Plans are created once and can be executed multiple times. The planning process may measure different algorithms to find the fastest.
Implementations
Sourceimpl<T: Float> Plan<T>
impl<T: Float> Plan<T>
Sourcepub fn dft_2d(
n0: usize,
n1: usize,
direction: Direction,
flags: Flags,
) -> Option<Plan2D<T>>
pub fn dft_2d( n0: usize, n1: usize, direction: Direction, flags: Flags, ) -> Option<Plan2D<T>>
Create a 2D complex-to-complex DFT plan.
Sourcepub fn dft_3d(
n0: usize,
n1: usize,
n2: usize,
direction: Direction,
flags: Flags,
) -> Option<Plan3D<T>>
pub fn dft_3d( n0: usize, n1: usize, n2: usize, direction: Direction, flags: Flags, ) -> Option<Plan3D<T>>
Create a 3D complex-to-complex DFT plan.
Sourcepub fn r2c_1d(n: usize, flags: Flags) -> Option<RealPlan<T>>
pub fn r2c_1d(n: usize, flags: Flags) -> Option<RealPlan<T>>
Create a 1D real-to-complex FFT plan.
Sourcepub fn c2r_1d(n: usize, flags: Flags) -> Option<RealPlan<T>>
pub fn c2r_1d(n: usize, flags: Flags) -> Option<RealPlan<T>>
Create a 1D complex-to-real FFT plan.
Sourcepub fn execute(&self, input: &[Complex<T>], output: &mut [Complex<T>])
pub fn execute(&self, input: &[Complex<T>], output: &mut [Complex<T>])
Execute the plan on the given input/output buffers.
Panics
Panics if input or output buffer sizes don’t match the plan size.
Sourcepub fn execute_inplace(&self, data: &mut [Complex<T>])
pub fn execute_inplace(&self, data: &mut [Complex<T>])