pub struct SplitPlan<T: Float> { /* private fields */ }Expand description
A plan for split-complex format (separate real and imaginary arrays).
Split-complex format stores the real parts in one array and the imaginary parts in another, rather than interleaving them:
- Interleaved:
[re0, im0, re1, im1, re2, im2, ...] - Split:
real = [re0, re1, re2, ...],imag = [im0, im1, im2, ...]
This format can be more efficient for SIMD processing and is used by some numerical libraries.
Example
ⓘ
use oxifft::{SplitPlan, Direction, Flags};
let n = 256;
let plan = SplitPlan::<f64>::dft_1d(n, Direction::Forward, Flags::ESTIMATE).unwrap();
let mut in_real = vec![0.0; n];
let mut in_imag = vec![0.0; n];
let mut out_real = vec![0.0; n];
let mut out_imag = vec![0.0; n];
// Initialize input...
in_real[0] = 1.0;
plan.execute(&in_real, &in_imag, &mut out_real, &mut out_imag);Implementations
Sourceimpl<T: Float> SplitPlan<T>
impl<T: Float> SplitPlan<T>
Sourcepub fn dft_1d(n: usize, direction: Direction, flags: Flags) -> Option<Self>
pub fn dft_1d(n: usize, direction: Direction, flags: Flags) -> Option<Self>
Create a 1D DFT plan for split-complex format.
Arguments
n- Transform sizedirection- Forward or Backwardflags- Planning flags