pub struct DiffFftPlan<T: Float> { /* private fields */ }Expand description
Differentiable FFT plan for automatic differentiation.
Wraps a standard FFT plan and provides differentiation capabilities.
Implementations
Sourceimpl<T: Float> DiffFftPlan<T>
impl<T: Float> DiffFftPlan<T>
Sourcepub fn inverse(&self, input: &[Complex<T>], output: &mut [Complex<T>])
pub fn inverse(&self, input: &[Complex<T>], output: &mut [Complex<T>])
Execute inverse FFT (normalized).
Sourcepub fn forward_dual(
&self,
input: &[DualComplex<T>],
) -> (Vec<Complex<T>>, Vec<Complex<T>>)
pub fn forward_dual( &self, input: &[DualComplex<T>], ) -> (Vec<Complex<T>>, Vec<Complex<T>>)
Compute forward FFT with its Jacobian-vector product (forward mode AD).
Given input x and tangent dx, computes:
- y = FFT(x)
- dy = FFT(dx) (the directional derivative)
Sourcepub fn backward(&self, grad_output: &[Complex<T>]) -> Vec<Complex<T>>
pub fn backward(&self, grad_output: &[Complex<T>]) -> Vec<Complex<T>>
Compute gradient of a scalar loss with respect to FFT input (backward mode AD).
Given the gradient of loss w.r.t. FFT output (grad_output), computes the gradient w.r.t. FFT input.
For FFT: y = F·x where F is the DFT matrix F[k,n] = exp(-2πi·k·n/N)
The adjoint F^H satisfies: <v, F·x> = <F^H·v, x>
F^H = conj(F^T) = IFFT_unnormalized = N · IFFT
Gradient: ∂L/∂x = F^H · ∂L/∂y = conj(FFT(conj(∂L/∂y)))
Sourcepub fn backward_inverse(&self, grad_output: &[Complex<T>]) -> Vec<Complex<T>>
pub fn backward_inverse(&self, grad_output: &[Complex<T>]) -> Vec<Complex<T>>
Compute gradient of a scalar loss with respect to IFFT input.
For normalized IFFT: y = (1/N)·Fᴴ·x The adjoint of (1/N)·Fᴴ is (1/N)·F Gradient: ∂L/∂x = (1/N)·F · ∂L/∂y = (1/N)·FFT(∂L/∂y)