pub struct R2cSolver<T: Float> { /* private fields */ }Expand description
Real-to-Complex FFT solver.
For a real input of size N, produces N/2+1 complex outputs. The output satisfies conjugate symmetry: X[k] = X[N-k]*.
Implementations
Sourceimpl<T: Float> R2cSolver<T>
impl<T: Float> R2cSolver<T>
Sourcepub fn output_size(&self) -> usize
pub fn output_size(&self) -> usize
Get the output complex size (N/2 + 1).
Sourcepub fn execute_inplace(&self, data: &mut [T])
pub fn execute_inplace(&self, data: &mut [T])
Execute R2C FFT in-place.
The input buffer is reinterpreted: first N real values are input, and first N/2+1 complex values will be output.
Safety
The buffer must have enough space for max(N, 2*(N/2+1)) elements when viewed as T.