pub fn pool_with_threads(num_threads: usize) -> RayonPoolExpand description
Get a thread pool with the specified number of threads.
When the threading feature is enabled, returns a RayonPool with
the specified thread count. Otherwise returns a SerialPool.